@@ -17,20 +17,20 @@
 #' @return a vector of methods for use by \code{\link{PSAboot}}
 getPSAbootMethods <- function() {
 	methods <- getOption('PSAboot.methods', default=c(
-		'Stratification'=boot.strata,
-		'ctree'=boot.ctree,
-		'rpart'=boot.rpart,
-		'Matching'=boot.matching,
-		'MatchIt'=boot.matchit))
+		'Stratification' = boot.strata,
+		'ctree' = boot.ctree,
+		'rpart' = boot.rpart,
+		'Matching' = boot.matching,
+		'MatchIt' = boot.matchit))
 	invisible(methods)
 }
 
-#' Bootstraping for propensity score analysis
+#' Bootstrapping for propensity score analysis
 #' 
 #' Bootstrapping has become a popular resampling method for estimating sampling
 #' distributions. And propensity score analysis (PSA) has become popular for estimating
 #' causal effects in observational studies. This function implements bootstrapping
-#' specifically for PSA. Like typical bootstrapping methods, this function estiamtes
+#' specifically for PSA. Like typical bootstrapping methods, this function estimates
 #' treatment effects for M random samples. However, unlike typical bootstrap methods,
 #' this function allows for separate sample sizes for treatment and control units.
 #' That is, under certain circumstances (e.g. when the ratio of treatment-to-control
@@ -39,7 +39,7 @@ getPSAbootMethods <- function() {
 #' sample.
 #' 
 #' @param Tr numeric (0 or 1) or logical vector of treatment indicators. 
-#' @param Y vector of outcome varaible.
+#' @param Y vector of outcome variable
 #' @param X matrix or data frame of covariates used to estimate the propensity scores.
 #' @param M number of bootstrap samples to generate.
 #' @param formu formula used for estimating propensity scores. The default is to use
@@ -48,7 +48,7 @@ getPSAbootMethods <- function() {
 #' @param control.sample.size the size of each bootstrap sample of control units.
 #' @param control.replace whether to use replacement when sampling from control units.
 #' @param treated.sample.size the size of each bootstrap sample of treatment units. The
-#'        default uses all treatment units for each boostrap sample.
+#'        default uses all treatment units for each bootstrap sample.
 #' @param treated.replace whether to use replacement when sampling from treated units.
 #' @param methods a named vector of functions for each PSA method to use.
 #' @param seed random seed. Each iteration, i, will use a seed of \code{seed + i}.
@@ -57,11 +57,11 @@ getPSAbootMethods <- function() {
 #' @return a list with following elements:
 #' 		  \describe{
 #' 		  \item{overall.summary}{Data frame with the results using the complete
-#' 		                         dateset (i.e. unboostrapped results).}
+#' 		                         dataset (i.e. unbootstrapped results).}
 #' 		  \item{overall.details}{Objects returned from each method for complete dataset.}
-#' 		  \item{pooled.summary}{Data frame with results of each boostrap sample.}
+#' 		  \item{pooled.summary}{Data frame with results of each bootstrap sample.}
 #' 		  \item{pooled.details}{List of objects returned from each method for each 
-#' 		        boostrap sample.}
+#' 		        bootstrap sample.}
 #' 		  \item{control.sample.size}{sample size used for control units.}
 #' 		  \item{treated.sample.size}{sample size used for treated units.}
 #' 		  \item{control.replace}{whether control units were sampled with replacement.}
@@ -73,17 +73,27 @@ getPSAbootMethods <- function() {
 #' 		  }
 #' @seealso getPSAbootMethods
 #' @export
-PSAboot <- function(Tr, Y, X, M=100,
-					formu=as.formula(paste0('treat ~ ', paste0(names(X), collapse=' + '))),
-					control.ratio=5,
-					control.sample.size=min(control.ratio*min(table(Tr)),
-											max(table(Tr))),
-					control.replace=TRUE,
-					treated.sample.size=min(table(Tr)),
-					treated.replace=TRUE,
-					methods=getPSAbootMethods(),
-					parallel=TRUE,
-					seed=NULL,
+#' @examples
+#' \donttest{
+#' library(PSAboot)
+#' data(pisa.psa.cols)
+#' data(pisausa)
+#' bm.usa <- PSAboot(Tr = as.integer(pisausa$PUBPRIV) - 1,
+#'     Y = pisausa$Math,
+#'     X = pisausa[,pisa.psa.cols],
+#'     control.ratio = 5, M = 100, seed = 2112)
+#' 
+#' }
+PSAboot <- function(Tr, Y, X, M = 100,
+					formu = as.formula(paste0('treat ~ ', paste0(names(X), collapse=' + '))),
+					control.ratio = 5,
+					control.sample.size = min(control.ratio*min(table(Tr)), max(table(Tr))),
+					control.replace = TRUE,
+					treated.sample.size = min(table(Tr)),
+					treated.replace = TRUE,
+					methods = getPSAbootMethods(),
+					parallel = TRUE,
+					seed = NULL,
 					...) {
 	if(length(Tr) != length(Y) & length(Y) != nrow(X)) {
 		stop('The length of Tr and Y and the number of rows of X must be the same!')
